ax_state library

Classes

AxCustomRouteObserver
Global RouteObserver strictly for tracking AxState screen visibility. Add this to your MaterialApp's navigatorObservers.
AxInitialState<T extends StatefulWidget>
Initial state class for the first screen of your application.
AxState<T extends StatefulWidget>
Replacement for the standard State class that provides automatic lifecycle tracking and memory leak detection.
FnAutomaticKeepAliveClientMixin<T extends StatefulWidget>

Properties

axRouteObserver AxCustomRouteObserver
final