didPop method
Called when the current route has been popped off.
Implementation
@override
void didPop() {
debugPrint('AxState: didPop called for $_effectiveStateName');
ActivityTrail().addMarker(_effectiveStateName, "didPop", true);
}
Called when the current route has been popped off.
@override
void didPop() {
debugPrint('AxState: didPop called for $_effectiveStateName');
ActivityTrail().addMarker(_effectiveStateName, "didPop", true);
}